# This file is dual licensed under the terms of the Apache License, Version
# 2.0, and the BSD License. See the LICENSE file in the root of this repository
# for complete details.

__all__ = [
    "__title__",
    "__summary__",
    "__uri__",
    "__version__",
    "__author__",
    "__email__",
    "__license__",
    "__copyright__",
]

__title__ = "cryptography_vectors"
__summary__ = "Test vectors for the cryptography package."

__uri__ = "https://github.com/pyca/cryptography"

__version__ = "3.4.8"

__author__ = "The Python Cryptographic Authority and individual contributors"
__email__ = "cryptography-dev@python.org"

__license__ = "BSD or Apache License, Version 2.0"
__copyright__ = "Copyright 2013-2021 %s" % __author__
